@@ -1,6 +1,6 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '1.001';
+$Import::Base::VERSION = '1.002';
 use strict;
 use warnings;
 use mro ();
@@ -199,7 +199,7 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -247,7 +247,7 @@ version 1.001
     use My::Base 'Test';
     use My::Base 'Class';
 
-    # Exclude some things we don't want
+    # Exclude some modules and symbols we don't want
     use My::Base -exclude => [ 'warnings', 'My::Exporter' => [ 'bar' ] ];
 
 =head1 DESCRIPTION
@@ -397,9 +397,9 @@ the value as the required version.
 
 =head2 -exclude
 
-When importing a base module, you can use C<-exclude> to prevent certain things
-from being imported (if, for example, they would conflict with existing
-things).
+When importing a base module, you can use C<-exclude> to prevent certain
+modules or symbols from being imported (if, for example, they would
+conflict with existing symbols).
 
     # Prevent the "warnings" module from being imported
     use My::Base -exclude => [ 'warnings' ];
